;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 1 test for TEB bands. Calculates the SNR and NEdT. Fits the SNR
;  to the Plank radiance of the BCS (using a function with Powell's method
;  or a cubic polynomial with poly_fit) with or without weights of 1/std.
;  RSR is implimented in rsr=0 and not in rsr=1.
;
;  Input:
;  1) Input file.
;
;  Output:
;  1) SNR[collect,band,HAM,detector,subsample]
;  2) snr_1[band,HAM,detector,subsample,coefficients,fit type,not weighted or weighted,rsr]
;  4) snr_fit[collect,band,HAM,detector,subsample,fit type,not weighted or weighted,rsr]
;  5) NEdL[collect,b,HAM,detector,subsample,fit type,not weighted or weighted,rsr]
;  6) NEdT[collect,band,HAM,detector,subsample,fit type,not weighted or weighted,rsr]
;  7) SNR_typ[band,HAM,detector,subsample,fit type,not weighted or weighted,rsr]
;  8) NEdL_typ[band,HAM,detector,subsample,fit type,not weighted or weighted,rsr]
;  9) NEdT_typ[band,HAM,detector,subsample,fit type,not weighted or weighted,rsr]
;
;  v1.0 - 04/3/2008 - Jeff McIntire
;*****************************************************************************

;*****************************************************************************
;  Functions for powell's method.
;*****************************************************************************

FUNCTION powfunc, xx

COMMON X1,b
COMMON X2,id
COMMON X3,ih
COMMON X4,is
COMMON X5,ncollects
COMMON X6,SNR
COMMON X7,rad_BCS
COMMON X8,lcol
COMMON X9,hcol
COMMON X10,w
COMMON X11,rsr
COMMON X12,L_typ_TEB

X=fltarr(ncollects)

Z=0
FOR col=lcol, hcol-1 DO BEGIN
	IF (xx[0]+xx[1]*rad_BCS[col,b,ih,id,is,rsr]+xx[2]*rad_BCS[col,b,ih,id,is,rsr]^2) LT 0 THEN RETURN,1000000
	IF (xx[0]+xx[1]*L_typ_TEB[b,0]+xx[2]*L_typ_TEB[b,0]^2) LT 0 THEN RETURN,1000000
	X[col]=rad_BCS[col,b,ih,id,is,rsr]-SNR[col,b,ih,id,is,1] $
		*sqrt(xx[0]+xx[1]*rad_BCS[col,b,ih,id,is,rsr]+xx[2]*rad_BCS[col,b,ih,id,is,rsr]^2)

	Z=Z+w[col]*X[col]^2/total(w)
ENDFOR

RETURN,Z

END

FUNCTION powfunc2, xy

COMMON X1,b
COMMON X2,id
COMMON X3,ih
COMMON X4,is
COMMON X5,ncollects
COMMON X6,SNR
COMMON X7,rad_BCS
COMMON X8,lcol
COMMON X9,hcol
COMMON X10,w
COMMON X11,rsr

Y=fltarr(ncollects)

Z=0
FOR col=lcol, hcol-1 DO BEGIN
	Y[col]=xy[0]+xy[1]*rad_BCS[col,b,ih,id,is,rsr]+xy[2]*rad_BCS[col,b,ih,id,is,rsr]^2-SNR[col,b,ih,id,is,1]

	Z=Z+w[col]*Y[col]^2/total(w)
ENDFOR

RETURN,Z

END

;*****************************************************************************
;  Main program.
;*****************************************************************************

PRO RC5_SNR_NEdT, infile

nlines=File_Lines(infile)
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
fnumber=fltarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

infname1=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
restore,infname1
restore,infname2
restore,infname3

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

outfile=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'

COMMON X1,b
COMMON X2,id
COMMON X3,ih
COMMON X4,is
COMMON X5,ncollects
COMMON X6,SNR
COMMON X7,rad_BCS
COMMON X8,lcol
COMMON X9,hcol
COMMON X10,w
COMMON X11,rsr
COMMON X12,L_typ_TEB

SNR=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
sigma_SNR=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)

;*****************************************************************************
;  Calculate the SNR (scan method).
;*****************************************************************************

maxscans=100

SNR_1=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,maxscans)
SNR_2=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets)
SNR_3=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,maxscans)

FOR col=0, ncollects-1 DO BEGIN
	FOR b=0, nbands_TEB-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			FOR is=0, subsets_TEB[b]-1 DO BEGIN
				FOR id=0, detectors_TEB[b]-1 DO BEGIN
			;		SNR_1[col,b,ih,id,is,0:maxscans-1]=dn_col[col,b,ih,id,is,0:maxscans-1,0] $
			;			/std_col[col,b,ih,id,is,0:maxscans-1,0]
			;		FOR iscans=0, maxscans-1 DO BEGIN
			;			IF std_col[col,b,ih,id,is,iscans,0] EQ 0 THEN SNR_1[col,b,ih,id,is,iscans]=0
			;		ENDFOR

			;		SNR_2[col,b,ih,id,is]=sig_mean(SNR_1[col,b,ih,id,is,0:maxscans-1],3,1)
			;		FOR iscans=0, maxscans-1 DO BEGIN
			;			SNR_3[col,b,ih,id,is,iscans] $
			;				=(SNR_1[col,b,ih,id,is,iscans]-SNR_2[col,b,ih,id,is])^2
			;		ENDFOR

			;		SNR[col,b,ih,id,is,0]=sig_mean(SNR_1[col,b,ih,id,is,0:maxscans-1],3,1)
			;		sigma_SNR[col,b,ih,id,is,0]=sqrt(sig_mean(SNR_3[col,b,ih,id,is,0:maxscans-1],3,1))
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Calculate the SNR (sample method).
;*****************************************************************************

;SNR_1=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,maxscans)
;SNR_2=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets)
;SNR_3=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,maxscans)

FOR col=0, ncollects-1 DO BEGIN
	FOR b=0, nbands_TEB-1 DO BEGIN
		IF band_type_TEB[b] EQ 1 THEN max_frame=400
		IF band_type_TEB[b] EQ 0 THEN max_frame=200
		FOR ih=0, nham-1 DO BEGIN
			FOR is=0, subsets_TEB[b]-1 DO BEGIN
				FOR id=0, detectors_TEB[b]-1 DO BEGIN
					SNR_1[col,b,ih,id,is,0:max_frame-1]=dn_col_2[col,b,ih,id,is,0:max_frame-1] $
						/std_col_2[col,b,ih,id,is,0:max_frame-1]
					FOR f=0, max_frame-1 DO BEGIN
						IF std_col_2[col,b,ih,id,is,f] EQ 0 THEN SNR_1[col,b,ih,id,is,f]=0
					ENDFOR

					SNR_2[col,b,ih,id,is]=sig_mean(SNR_1[col,b,ih,id,is,0:max_frame-1],3,1)
					FOR f=0, max_frame-1 DO BEGIN
						SNR_3[col,b,ih,id,is,f]=(SNR_1[col,b,ih,id,is,f]-SNR_2[col,b,ih,id,is])^2
					ENDFOR

					SNR[col,b,ih,id,is,1]=sig_mean(SNR_1[col,b,ih,id,is,0:max_frame-1],3,1)
					sigma_SNR[col,b,ih,id,is,1]=sqrt(sig_mean(SNR_3[col,b,ih,id,is,0:max_frame-1],3,1))
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Calculate the SNR (overall method).
;*****************************************************************************

;SNR[*,*,*,*,*,2]=dn[*,*,*,*,*,2]/std[*,*,*,*,*,2]
;sigma_SNR[*,*,*,*,*,2]=std[*,*,*,*,*,2]

;*****************************************************************************
;  Powell's method for fitting SNR to BCS radiance (function and quadratic polynomial).
;*****************************************************************************

w=dblarr(ncollects)

snr_1=dblarr(nbands_TEB,nham,maxdet,maxsubsets,4,2,2,2)
snr_fit=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,2,2)

FOR ifit=0, 1 DO BEGIN
	; 0 for rsr correction and 1 for no rsr correction.
	FOR rsr=0, 1 DO BEGIN
		FOR b=0, nbands_TEB-1 DO BEGIN
			FOR is=0, subsets_TEB[b]-1 DO BEGIN
				FOR ih=0, nham-1 DO BEGIN
					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						lcol=0
						hcol=ncollects
						FOR col=0, ncollects-1 DO BEGIN
							IF rad_BCS[col,b,ih,id,is,rsr] LT L_min_TEB[b,0] THEN lcol=lcol+1
							IF rad_BCS[col,b,ih,id,is,rsr] GT L_max_TEB[b,0] THEN hcol=hcol-1
						ENDFOR

						IF ifit EQ 0 THEN w[*]=1.0
						IF ifit EQ 1 THEN w[*]=1/sigma_SNR[*,b,ih,id,is,1]^2

						P1=[.000001,.000001,.000001]
						ftol=0.00000001
						xi=TRANSPOSE([[0.0,1.0,0.0],[0.0,0.0,1.0],[1.0,0.0,0.0]])

						powell,P1,xi,ftol,fmin,'powfunc',/DOUBLE,ITMAX=1000
						snr_1[b,ih,id,is,0:2,0,ifit,rsr]=P1[0:2]

						P2=[.0001,.0001,.0001]
						ftol=0.00000001
						xi=TRANSPOSE([[0.0,1.0,0.0],[0.0,0.0,1.0],[1.0,0.0,0.0]])

						powell,P2,xi,ftol,fmin,'powfunc2',/DOUBLE,ITMAX=1000
						snr_1[b,ih,id,is,0:2,1,ifit,rsr]=P2[0:2]

					;	print,ifit,rsr,b,id,ih,is,P1[0],P1[1],P1[2],fmin,P2[0],P2[1],P2[2]

						snr_fit[*,b,ih,id,is,0,ifit,rsr]=(SNR[*,b,ih,id,is,1] $
							-(rad_BCS[*,b,ih,id,is,rsr]) $
							/sqrt(P1[0]+P1[1]*rad_BCS[*,b,ih,id,is,rsr] $
							+P1[2]*rad_BCS[*,b,ih,id,is,rsr]^2))/SNR[*,b,ih,id,is,1]
						snr_fit[*,b,ih,id,is,1,ifit,rsr]=(SNR[*,b,ih,id,is,1]-P2[0] $
							-P2[1]*rad_BCS[*,b,ih,id,is,rsr] $
							-P2[2]*rad_BCS[*,b,ih,id,is,rsr]^2)/SNR[*,b,ih,id,is,1]
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Calulate the NEdL and NEdT.
;*****************************************************************************

NEdL=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,2,2)
NEdT=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2,2,2)
SNR_typ=dblarr(nbands_TEB,nham,maxdet,maxsubsets,2,2,2)
NEdL_typ=dblarr(nbands_TEB,nham,maxdet,maxsubsets,2,2,2)
NEdT_typ=dblarr(nbands_TEB,nham,maxdet,maxsubsets,2,2,2)

; 0 for rsr correction and 1 for no rsr correction.
FOR rsr=0, 1 DO BEGIN
	FOR ifit1=0, 1 DO BEGIN
		FOR b=0, nbands_TEB-1 DO BEGIN
			FOR col=0, ncollects-1 DO BEGIN
				FOR ifit2=0, 1 DO BEGIN
					NEdL[col,b,*,*,*,ifit2,ifit1,rsr]=rad_BCS[col,b,*,*,*,rsr]/SNR[col,b,*,*,*,1]
					NEdT[col,b,*,*,*,ifit2,ifit1,rsr]=NEdL[col,b,*,*,*,ifit2,ifit1,rsr] $
						/Planck_deriv(T_bcs[col],lambda_TEB[b])
				ENDFOR
			ENDFOR
			FOR ih=0, nham-1 DO BEGIN
				FOR is=0, subsets_TEB[b]-1 DO BEGIN
					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						SNR_typ[b,ih,id,is,0,ifit1,rsr]=L_typ_TEB[b,0] $
							/sqrt(snr_1[b,ih,id,is,0,0,ifit1,rsr] $
							+snr_1[b,ih,id,is,1,0,ifit1,rsr]*L_typ_TEB[b,0] $
							+snr_1[b,ih,id,is,2,0,ifit1,rsr]*L_typ_TEB[b,0]^2)
						NEdL_typ[b,ih,id,is,0,ifit1,rsr]=sqrt(snr_1[b,ih,id,is,0,0,ifit1,rsr] $
							+snr_1[b,ih,id,is,1,0,ifit1,rsr]*L_typ_TEB[b,0] $
							+snr_1[b,ih,id,is,2,0,ifit1,rsr]*L_typ_TEB[b,0]^2)
						NEdT_typ[b,ih,id,is,0,ifit1,rsr]=NEdL_typ[b,ih,id,is,0,ifit1,rsr] $
							/Planck_deriv(T_typ_TEB[b],lambda_TEB[b])
						NEdL_typ[b,ih,id,is,1,ifit1,rsr]=L_typ_TEB[b,0] $
							/(snr_1[b,ih,id,is,0,1,ifit1,rsr] $
							+snr_1[b,ih,id,is,1,1,ifit1,rsr]*L_typ_TEB[b,0] $
							+snr_1[b,ih,id,is,2,1,ifit1,rsr]*L_typ_TEB[b,0]^2 $
							+snr_1[b,ih,id,is,3,1,ifit1,rsr]*L_typ_TEB[b,0]^3)
						NEdT_typ[b,ih,id,is,1,ifit1,rsr]=NEdL_typ[b,ih,id,is,1,ifit1,rsr]$
							/Planck_deriv(T_typ_TEB[b],lambda_TEB[b])
					ENDFOR
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR
print,'Band    SNR_typ    NEdt_typ    (detector and subsample averaged)'
FOR b=0, nbands_TEB-1 DO BEGIN
	print,b,mean(SNR_typ[b,0,0:detectors_TEB[b]-1,0:subsets_TEB[b]-1,0,1,0]), $
		mean(NEdT_typ[b,0,0:detectors_TEB[b]-1,0:subsets_TEB[b]-1,0,1,0])
ENDFOR

;*****************************************************************************
;  Output SNR and NEdT to txt and sav files.
;*****************************************************************************

outfile2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr_typ.txt'
outfile3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.NEdT_typ.txt'

fmt_1='(i2, 5x, i3, 5x, i2, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f)'

openw,lun,outfile2,/get_lun
printf,lun,'Signal to Noise Ratio (SNR) at T_typ (averaged over subsample, with weighted fits with RSR)'
printf,lun,'HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR id=0, maxdet-1 DO BEGIN
		IF id LT 16 THEN printf,lun,format=fmt_1,ih,id,mean(SNR_typ[0,ih,id,0:1,0,1,0]), $
			mean(SNR_typ[1,ih,id,0:1,0,1,0]),SNR_typ[2,ih,id,0,0,1,0],SNR_typ[3,ih,id,0,0,1,0], $
			SNR_typ[4,ih,id,0,0,1,0],SNR_typ[5,ih,id,0,0,1,0],SNR_typ[6,ih,id,0,0,1,0],SNR_typ[7,ih,id,0,0,1,0]
		IF id GE 16 THEN printf,lun,format=fmt_1,ih,mean(SNR_typ[0,ih,id,0:1,0,1,0]),mean(SNR_typ[1,ih,id,0:1,0,1,0]), $
			0.0,0.0,0.0,0.0,0.0,0.0
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile3,/get_lun
printf,lun,'Noise Equivalent detla Temperature (NEdT) at T_typ (averaged over subsample, with weighted fits with RSR)'
printf,lun,'HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR id=0, maxdet-1 DO BEGIN
		IF id LT 16 THEN printf,lun,format=fmt_1,ih,id,mean(NEdT_typ[0,ih,id,0:1,0,1,0]), $
			mean(NEdT_typ[1,ih,id,0:1,0,1,0]),NEdT_typ[2,ih,id,0,0,1,0],NEdT_typ[3,ih,id,0,0,1,0], $
			NEdT_typ[4,ih,id,0,0,1,0],NEdT_typ[5,ih,id,0,0,1,0],NEdT_typ[6,ih,id,0,0,1,0],NEdT_typ[7,ih,id,0,0,1,0]
		IF id GE 16 THEN printf,lun,format=fmt_1,ih,mean(NEdT_typ[0,ih,id,0:1,0,1,0]), $
			mean(NEdT_typ[1,ih,id,0:1,0,1,0]),0.0,0.0,0.0,0.0,0.0,0.0
	ENDFOR
ENDFOR
free_lun,lun
close,lun,/file,/all

save,/compress,SNR,SNR_typ,snr_1,snr_fit,NEdL,NEdT,NEdL_typ,NEdT_typ,filename=outfile

END
