;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 1 test for TEB bands. Calculates the background subtracted DN and
;  standard deviations.
;
;  Input:
;  1) File with inpath and outpath.
;
;  Output:
;  1) dn(collect,band,HAM,detector,subsample,3] -- dn for frame average then scan average,
;     scan average then frame average, and average over all scans and frames 
;     with a 3 sigma kick out at each step.
;  2) std(collect,band,HAM,detector,subsample,3] -- std for frame average then scan average,
;     scan average then frame average, and average over all scans and frames 
;     with a 3 sigma kick out at each step.
;  3) dn_obc(collect,band,HAM,detector,subsample,3] -- dn_obc for frame average then scan average,
;     scan average then frame average, and average over all scans and frames 
;     with a 3 sigma kick out at each step.
;  4) std_obc(collect,band,HAM,detector,subsample,3] -- std_obc for frame average then scan average,
;     scan average then frame average, and average over all scans and frames 
;     with a 3 sigma kick out at each step.
;  5) slope1(collect,band,HAM,detector,subsample,scan,2] -- coefficients from a straight line fit to
;     the dn versus frame.
;  6) slope2(collect,band,HAM,detector,subsample,2] -- coefficients from a straight line fit to
;     the dn versus scan.
;  7) slope1_obc(collect,band,HAM,detector,subsample,scan,2] -- coefficients from a straight line fit to
;     the dn_obc versus frame.
;  8) slope2_obc(collect,band,HAM,detector,subsample,2] -- coefficients from a straight line fit to
;     the dn_obc versus scan.
;  9) dn_col(collect,band,HAM,detector,subsample,scan,3] -- dn for frame average with a 3 sigma kick 
;     out at each step for (0=EV, 1=SV, 2=OBC). The EV and OBC indices are SV subtracted.
;  10) std_col(collect,band,HAM,detector,subsample,scan,3] -- std for frame average with a 3 sigma kick 
;     out at each step for (0=EV, 1=SV, 2=OBC). The EV and OBC indices are SV subtracted.
;  
;  v1.0 - 04/01/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_dn_3, infile

;*****************************************************************************
;  Read in input file, sav TEB file, and get list of dump files.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)		; RVS .sav file.
param_in=strarr(1)		; EDU coeff .sav file.
rsrpath=strarr(1)		; RSR .sav file.
fnumber=strarr(1)
header_size=intarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
readf,lun,header_size
Free_Lun,lun

n_collect,inpath,ncollects,type,0

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

; Get list of .dmp files from specified path. 
spawn, 'ls -C1 ' + inpath + '*.dmp', list_files
IF N_ELEMENTS(list_files) EQ 0 THEN goto,skipout
nfile=N_ELEMENTS(list_files)

;*****************************************************************************
;  Some definitions.
;*****************************************************************************

max_scan=100					; Total # scans.

outfile=' '					; Output file name, which is reasigned.

; DN values per collect (0=EV, 1=SV, 2=OBC).
dn_col=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,max_scan,3)
dn_col_2=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,400)

; Final dn (0=frame,scan 1=scan,frame 2frame+scan).
dn=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
dn_obc=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)

; STD values per collect (0=EV, 1=SV, 2=OBC).
std_col=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,max_scan,3)
std_col_2=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,400)

; Final std (0=frame,scan 1=scan,frame 2frame+scan).
std=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
std_obc=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)

; Drifting check.
slope1=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,max_scan,2)
slope2=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2)
slope_obc1=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,max_scan,2)
slope_obc2=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,2)

;*****************************************************************************
;  Read in the dump files for SV.
;*****************************************************************************

m=0
a5=0
FOR ifile=0, nfile-1 DO BEGIN

	nlines=File_Lines(list_files[ifile])
	IF nlines EQ 0 THEN continue

	; Determine the relative collect #.
	m=m+1
	IF m EQ 25 THEN BEGIN
		a5=a5+1
		m=1
	ENDIF

	a2=strsplit(list_files[ifile],'/',/Extract)
	a3=N_ELEMENTS(a2)
	a4=strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)+1,1)		; Determine I or M band.
	a8=strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+10,2)		; Determine EV or SV.

	; Keep only the SV.
	IF a8 NE 'SV' THEN continue
	print,list_files[ifile]

	read_dmpd2,list_files[ifile],header_size,uaid,collect,scan,ham,apid,band,dnb_s,det,dsect,frame,offset,gain_type,dns

	; Translate the band name to a number.
	IF band[0] EQ 'I4' THEN b=0
	IF band[0] EQ 'I5' THEN b=1
	IF band[0] EQ 'M12' THEN b=2
	IF band[0] EQ 'M13' THEN b=3
	IF band[0] EQ 'M14' THEN b=4
	IF band[0] EQ 'M15' THEN b=5
	IF band[0] EQ 'M16A' THEN b=6
	IF band[0] EQ 'M16B' THEN b=7

	IF band_type_TEB[b] EQ 1 THEN max_frame=96		; Total # frames (I band).
	IF band_type_TEB[b] EQ 0 THEN max_frame=48		; Total # frames (M band).

;*****************************************************************************
;  Write DN values to an array for SV.
;*****************************************************************************

	dn_frame=dblarr(nham,maxdet,maxsubsets,max_scan,max_frame)
	iscan=0
	idet=0
	iframe=0
	subset=0
	FOR i=0L, nlines-1 DO BEGIN
		IF scan[i] EQ iscan+1 AND det[i] EQ idet+1 THEN BEGIN
			dn_frame[ham[i],idet,subset,iscan,iframe]=dns[i]
			iframe=iframe+1
			IF iframe EQ max_frame THEN BEGIN
				idet=idet+1
				iframe=0
				IF idet EQ detectors_TEB[b] THEN BEGIN
					idet=0
					iscan=iscan+1
				ENDIF
			ENDIF
		ENDIF
		IF band_type_TEB[b] EQ 1 THEN BEGIN
			IF subset EQ 0 THEN BEGIN
				subset=1
				goto,skip_over_1
			ENDIF
			IF subset EQ 1 THEN subset=0
			skip_over_1:
		ENDIF
	ENDFOR

;*****************************************************************************
;  Average over frames and calculate the standard deviation.
;*****************************************************************************

	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				FOR iscan=0, max_scan-1 DO BEGIN
					dn_col[a5,b,iham,idet,isubset,iscan,1]= $
						sig_mean(dn_frame[iham,idet,isubset,iscan,0:max_frame-1],3,1)
					std_col[a5,b,iham,idet,isubset,iscan,1]= $
						sig_mean(dn_frame[iham,idet,isubset,iscan,0:max_frame-1],3,2)

					IF dn_col[a5,b,iham,idet,isubset,iscan,1] EQ -999 THEN $
						dn_col[a5,b,iham,idet,isubset,iscan,1]=0
					IF std_col[a5,b,iham,idet,isubset,iscan,1] EQ -999 THEN $
						std_col[a5,b,iham,idet,isubset,iscan,1]=0
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Relabel the higher subsample as 0 and the lower as 1.
;*****************************************************************************

	temp1=dblarr(nham,maxdet,maxsubsets,max_scan)
	IF a4 EQ 'I' THEN BEGIN
		FOR iham=0, nham-1 DO BEGIN
			FOR idet=0, detectors_TEB[b]-1 DO BEGIN
				FOR iscan=0, max_scan-1 DO BEGIN
					IF dn_col[a5,b,iham,idet,0,iscan,1] GT dn_col[a5,b,iham,idet,1,iscan,1] THEN BEGIN
						temp1[iham,idet,0,iscan]=dn_col[a5,b,iham,idet,0,iscan,1]
						temp1[iham,idet,1,iscan]=dn_col[a5,b,iham,idet,1,iscan,1]
					ENDIF ELSE BEGIN
						temp1[iham,idet,0,iscan]=dn_col[a5,b,iham,idet,1,iscan,1]
						temp1[iham,idet,1,iscan]=dn_col[a5,b,iham,idet,0,iscan,1]
					ENDELSE
				ENDFOR
			ENDFOR
		ENDFOR
		dn_col[a5,b,*,*,0,*,1]=temp1[*,*,0,*]
		dn_col[a5,b,*,*,1,*,1]=temp1[*,*,1,*]
	ENDIF
ENDFOR

;*****************************************************************************
;  Read in the dump files for EV and OBC.
;*****************************************************************************

q=0
a5=0
FOR ifile=0, nfile-1 DO BEGIN

	nlines=File_Lines(list_files[ifile])
	IF nlines EQ 0 THEN continue

	; Determine the relative collect #.
	q=q+1
	IF q EQ 25 THEN BEGIN
		a5=a5+1
		q=1
	ENDIF

	a2=strsplit(list_files[ifile],'/',/Extract)
	a3=N_ELEMENTS(a2)
	a4=strmid(a2[a3-1],strpos(a2[a3-1],'_',/Reverse_Search)+1,1)		; Determine I or M band.
	a8=strmid(a2[a3-1],strpos(a2[a3-1],'/',/Reverse_Search)+10,2)		; Determine EV or SV.

	; Output file name.
	outfile='/home/jmcintire/VIIRS_Data/RC_5_EDU/'+a2[a3-4]+'/'+a2[a3-3]+'/'+a2[a3-4]+'.'+a2[a3-3]+'.dn.sav'

	; Keep only the EV and OBC.
	IF a8 EQ 'SV' THEN continue
	print,list_files[ifile]

	IF a8 EQ 'EV' THEN read_dmpd2,list_files[ifile],header_size,uaid,collect,scan,ham,apid,band,dnb_s, $
		det,dsect,frame,offset,gain_type,dns
	IF a8 EQ 'OB' THEN read_dmpd2,list_files[ifile],header_size,uaid,collect,scan,ham,apid,band,dnb_s, $
		det,dsect,frame,offset,gain_type,dns

	; Translate the band name to a number.
	IF band[0] EQ 'I4' THEN b=0
	IF band[0] EQ 'I5' THEN b=1
	IF band[0] EQ 'M12' THEN b=2
	IF band[0] EQ 'M13' THEN b=3
	IF band[0] EQ 'M14' THEN b=4
	IF band[0] EQ 'M15' THEN b=5
	IF band[0] EQ 'M16A' THEN b=6
	IF band[0] EQ 'M16B' THEN b=7

	IF a8 EQ 'EV' THEN BEGIN
		IF band_type_TEB[b] EQ 1 THEN max_frame=400		; Total # frames (I band).
		IF band_type_TEB[b] EQ 0 THEN max_frame=200		; Total # frames (M band).
	ENDIF
	IF a8 EQ 'OB' THEN BEGIN
		IF band_type_TEB[b] EQ 1 THEN max_frame=96		; Total # frames (I band).
		IF band_type_TEB[b] EQ 0 THEN max_frame=48		; Total # frames (M band).
	ENDIF

;*****************************************************************************
;  Write DN values to an array for EV and OBC.
;*****************************************************************************

	dn_frame=dblarr(nham,maxdet,maxsubsets,max_scan,max_frame)
	iscan=0
	idet=0
	iframe=0
	subset=0
	FOR i=0L, nlines-1 DO BEGIN
		IF scan[i] EQ iscan+1 AND det[i] EQ idet+1 THEN BEGIN
			dn_frame[ham[i],idet,subset,iscan,iframe]=dns[i]
			iframe=iframe+1
			IF iframe EQ max_frame THEN BEGIN
				idet=idet+1
				iframe=0
				IF idet EQ detectors_TEB[b] THEN BEGIN
					idet=0
					iscan=iscan+1
				ENDIF
			ENDIF
		ENDIF
		IF band_type_TEB[b] EQ 1 THEN BEGIN
			IF subset EQ 0 THEN BEGIN
				subset=1
				goto,skip_over_2
			ENDIF
			IF subset EQ 1 THEN subset=0
			skip_over_2:
		ENDIF
	ENDFOR

;*****************************************************************************
;  Subtract the SV average over frames from each frame of EV and OBC.
;*****************************************************************************

	dn_col_1=dblarr(nham,maxdet,maxsubsets,max_scan,max_frame,2)		; (0=EV, 1=OBC)
	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				IF a8 EQ 'EV' THEN BEGIN
					FOR iscan=0, max_scan-1 DO BEGIN
						IF sig_mean(dn_frame[iham,idet,0,iscan,0:max_frame-1],3,1) GT $
							sig_mean(dn_frame[iham,idet,1,iscan,0:max_frame-1],3,1) THEN flag=0
						IF sig_mean(dn_frame[iham,idet,0,iscan,0:max_frame-1],3,1) LT $
							sig_mean(dn_frame[iham,idet,1,iscan,0:max_frame-1],3,1) THEN flag=1
						IF sig_mean(dn_frame[iham,idet,0,iscan,0:max_frame-1],3,1) EQ -999 AND $
							sig_mean(dn_frame[iham,idet,1,iscan,0:max_frame-1],3,1) EQ -999 $
							THEN continue

						FOR iframe=0, max_frame-1 DO BEGIN
							IF band_type_TEB[b] EQ 1 THEN BEGIN
								IF dn_frame[iham,idet,isubset,iscan,iframe] $
									NE 0 AND flag EQ 0 THEN BEGIN

									dn_col_1[iham,idet,isubset,iscan,iframe,0]= $
									dn_frame[iham,idet,isubset,iscan,iframe] $
									-dn_col[a5,b,iham,idet,isubset,iscan,1]
								ENDIF
								IF dn_frame[iham,idet,isubset,iscan,iframe] $
									NE 0 AND flag EQ 1 THEN BEGIN

									IF isubset EQ 0 THEN $
										dn_col_1[iham,idet,isubset,iscan,iframe,0]= $
										dn_frame[iham,idet,isubset,iscan,iframe] $
										-dn_col[a5,b,iham,idet,1,iscan,1]
									IF isubset EQ 1 THEN $
										dn_col_1[iham,idet,isubset,iscan,iframe,0]= $
										dn_frame[iham,idet,isubset,iscan,iframe] $
										-dn_col[a5,b,iham,idet,0,iscan,1]
								ENDIF
								IF dn_frame[iham,idet,isubset,iscan,iframe] EQ 0 THEN $
									dn_col_1[iham,idet,isubset,iscan,iframe,0]=0
							ENDIF
							IF band_type_TEB[b] EQ 0 THEN BEGIN
								IF dn_frame[iham,idet,isubset,iscan,iframe] NE 0 THEN $
									dn_col_1[iham,idet,isubset,iscan,iframe,0]= $
									dn_frame[iham,idet,isubset,iscan,iframe] $
									-dn_col[a5,b,iham,idet,isubset,iscan,1]
								IF dn_frame[iham,idet,isubset,iscan,iframe] EQ 0 THEN $
									dn_col_1[iham,idet,isubset,iscan,iframe,0]=0
							ENDIF
						ENDFOR
					ENDFOR
				ENDIF
				IF a8 EQ 'OB' THEN BEGIN
					FOR iscan=0, max_scan-1 DO BEGIN
						IF sig_mean(dn_frame[iham,idet,0,iscan,0:max_frame-1],3,1) GT $
							sig_mean(dn_frame[iham,idet,1,iscan,0:max_frame-1],3,1) THEN flag=0
						IF sig_mean(dn_frame[iham,idet,0,iscan,0:max_frame-1],3,1) LT $
							sig_mean(dn_frame[iham,idet,1,iscan,0:max_frame-1],3,1) THEN flag=1
						IF sig_mean(dn_frame[iham,idet,0,iscan,0:max_frame-1],3,1) EQ -999 AND $
							sig_mean(dn_frame[iham,idet,1,iscan,0:max_frame-1],3,1) EQ -999 $
							THEN continue

						FOR iframe=0, max_frame-1 DO BEGIN
							IF band_type_TEB[b] EQ 1 THEN BEGIN
								IF dn_frame[iham,idet,isubset,iscan,iframe] $
									NE 0 AND flag EQ 0 THEN BEGIN

									dn_col_1[iham,idet,isubset,iscan,iframe,1]= $
									dn_frame[iham,idet,isubset,iscan,iframe] $
									-dn_col[a5,b,iham,idet,isubset,iscan,1]
								ENDIF
								IF dn_frame[iham,idet,isubset,iscan,iframe] $
									NE 0 AND flag EQ 1 THEN BEGIN

									IF isubset EQ 0 THEN $
										dn_col_1[iham,idet,isubset,iscan,iframe,1]= $
										dn_frame[iham,idet,isubset,iscan,iframe] $
										-dn_col[a5,b,iham,idet,1,iscan,1]
									IF isubset EQ 1 THEN $
										dn_col_1[iham,idet,isubset,iscan,iframe,1]= $
										dn_frame[iham,idet,isubset,iscan,iframe] $
										-dn_col[a5,b,iham,idet,0,iscan,1]
								ENDIF
								IF dn_frame[iham,idet,isubset,iscan,iframe] EQ 0 THEN $
									dn_col_1[iham,idet,isubset,iscan,iframe,1]=0
							ENDIF
							IF band_type_TEB[b] EQ 0 THEN BEGIN
								IF dn_frame[iham,idet,isubset,iscan,iframe] NE 0 THEN $
									dn_col_1[iham,idet,isubset,iscan,iframe,1]= $
									dn_frame[iham,idet,isubset,iscan,iframe] $
									-dn_col[a5,b,iham,idet,isubset,iscan,1]
								IF dn_frame[iham,idet,isubset,iscan,iframe] EQ 0 THEN $
									dn_col_1[iham,idet,isubset,iscan,iframe,1]=0
							ENDIF
						ENDFOR
					ENDFOR
				ENDIF
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Average over frames with standard deviation.
;*****************************************************************************

	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				FOR iscan=0, max_scan-1 DO BEGIN
					IF a8 EQ 'EV' THEN BEGIN
						dn_col[a5,b,iham,idet,isubset,iscan,0]= $
							sig_mean(dn_col_1[iham,idet,isubset,iscan,0:max_frame-1,0],3,1)
						std_col[a5,b,iham,idet,isubset,iscan,0]= $
							sig_mean(dn_col_1[iham,idet,isubset,iscan,0:max_frame-1,0],3,2)

						IF dn_col[a5,b,iham,idet,isubset,iscan,0] EQ -999 THEN $
							dn_col[a5,b,iham,idet,isubset,iscan,0]=0
						IF std_col[a5,b,iham,idet,isubset,iscan,0] EQ -999 THEN $
							std_col[a5,b,iham,idet,isubset,iscan,0]=0
					ENDIF
					IF a8 EQ 'OB' THEN BEGIN
						dn_col[a5,b,iham,idet,isubset,iscan,2]= $
							sig_mean(dn_col_1[iham,idet,isubset,iscan,0:max_frame-1,1],3,1)
						std_col[a5,b,iham,idet,isubset,iscan,2]= $
							sig_mean(dn_col_1[iham,idet,isubset,iscan,0:max_frame-1,1],3,2)

						IF dn_col[a5,b,iham,idet,isubset,iscan,2] EQ -999 THEN $
							dn_col[a5,b,iham,idet,isubset,iscan,2]=0
						IF std_col[a5,b,iham,idet,isubset,iscan,2] EQ -999 THEN $
							std_col[a5,b,iham,idet,isubset,iscan,2]=0
					ENDIF
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Average the dn over scans and average the standard deviations.
;*****************************************************************************

	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				IF a8 EQ 'EV' THEN BEGIN
;if idet eq 8 and isubset eq 0 then print,dn_col[a5,b,iham,idet,isubset,0:max_scan-1,0]
					dn[a5,b,iham,idet,isubset,0]=sig_mean(dn_col[a5,b,iham,idet,isubset,0:max_scan-1,0],3,1)
					std[a5,b,iham,idet,isubset,0] $
						=sig_mean(std_col[a5,b,iham,idet,isubset,0:max_scan-1,0],3,1)

					IF dn[a5,b,iham,idet,isubset,0] EQ -999 THEN dn[a5,b,iham,idet,isubset,0]=0
					IF std[a5,b,iham,idet,isubset,0] EQ -999 THEN std[a5,b,iham,idet,isubset,0]=0
				ENDIF
				IF a8 EQ 'OB' THEN BEGIN
					dn_obc[a5,b,iham,idet,isubset,0] $
						=sig_mean(dn_col[a5,b,iham,idet,isubset,0:max_scan-1,2],3,1)
					std_obc[a5,b,iham,idet,isubset,0] $
						=sig_mean(std_col[a5,b,iham,idet,isubset,0:max_scan-1,2],3,1)

					IF dn_obc[a5,b,iham,idet,isubset,0] EQ -999 THEN dn_obc[a5,b,iham,idet,isubset,0]=0
					IF std_obc[a5,b,iham,idet,isubset,0] EQ -999 THEN std_obc[a5,b,iham,idet,isubset,0]=0
				ENDIF
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Calculate the dn and standard deviation over scans, then average over frames.
;*****************************************************************************

	dn_scan_avg=dblarr(nham,maxdet,maxsubsets,max_frame,2)		; (0=EV and 1=OBC)
	std_scan_avg=dblarr(nham,maxdet,maxsubsets,max_frame,2)
	dn_avg_over_frames=dblarr(nham,maxdet,maxsubsets,2)
	std_avg_over_frames=dblarr(nham,maxdet,maxsubsets,2)
	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				IF a8 EQ 'EV' THEN BEGIN
					FOR iframe=0, max_frame-1 DO BEGIN
						dn_scan_avg[iham,idet,isubset,iframe,0]= $
							sig_mean(dn_col_1[iham,idet,isubset,0:max_scan-1,iframe,0],3,1)
						std_scan_avg[iham,idet,isubset,iframe,0]= $
							sig_mean(dn_col_1[iham,idet,isubset,0:max_scan-1,iframe,0],3,2)
	
						IF dn_scan_avg[iham,idet,isubset,iframe,0] EQ -999 THEN $
							dn_scan_avg[iham,idet,isubset,iframe,0]=0
						IF std_scan_avg[iham,idet,isubset,iframe,0] EQ -999 THEN $
							std_scan_avg[iham,idet,isubset,iframe,0]=0
					ENDFOR
					dn_avg_over_frames[iham,idet,isubset,0]= $
						sig_mean(dn_scan_avg[iham,idet,isubset,0:max_frame-1,0],3,1)
					std_avg_over_frames[iham,idet,isubset,0]= $
						sig_mean(std_scan_avg[iham,idet,isubset,0:max_frame-1,0],3,1)
				ENDIF
				IF a8 EQ 'OB' THEN BEGIN
					FOR iframe=0, max_frame-1 DO BEGIN
						dn_scan_avg[iham,idet,isubset,iframe,1]= $
							sig_mean(dn_col_1[iham,idet,isubset,0:max_scan-1,iframe,1],3,1)
						std_scan_avg[iham,idet,isubset,iframe,1]= $
							sig_mean(dn_col_1[iham,idet,isubset,0:max_scan-1,iframe,1],3,2)
	
						IF dn_scan_avg[iham,idet,isubset,iframe,1] EQ -999 THEN $
							dn_scan_avg[iham,idet,isubset,iframe,1]=0
						IF std_scan_avg[iham,idet,isubset,iframe,1] EQ -999 THEN $
							std_scan_avg[iham,idet,isubset,iframe,1]=0
					ENDFOR
					dn_avg_over_frames[iham,idet,isubset,1]= $
						sig_mean(dn_scan_avg[iham,idet,isubset,0:max_frame-1,1],3,1)
					std_avg_over_frames[iham,idet,isubset,1]= $
						sig_mean(std_scan_avg[iham,idet,isubset,0:max_frame-1,1],3,1)
				ENDIF
			ENDFOR
		ENDFOR
	ENDFOR
	IF a8 EQ 'EV' THEN dn[a5,b,*,*,*,1]=dn_avg_over_frames[*,*,*,0]
	IF a8 EQ 'EV' THEN std[a5,b,*,*,*,1]=std_avg_over_frames[*,*,*,0]
	IF a8 EQ 'EV' THEN dn_col_2[a5,b,*,*,*,0:max_frame-1]=dn_scan_avg[*,*,*,0:max_frame-1,0]
	IF a8 EQ 'EV' THEN std_col_2[a5,b,*,*,*,0:max_frame-1]=std_scan_avg[*,*,*,0:max_frame-1,0]
	IF a8 EQ 'OB' THEN dn_obc[a5,b,*,*,*,1]=dn_avg_over_frames[*,*,*,1]
	IF a8 EQ 'OB' THEN std_obc[a5,b,*,*,*,1]=std_avg_over_frames[*,*,*,1]

;*****************************************************************************
;  Calculate the dn and standard deviation over scans and frames.
;*****************************************************************************

	m=long(max_frame)
	n=long(max_scan)*long(max_frame)
	dn_total=dblarr(nham,maxdet,maxsubsets,2)		; (0=EV and 1=OBC)
	std_total=dblarr(nham,maxdet,maxsubsets,2)
	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				k=0
				p=0L
				temp=dblarr(n/2)
				temp_obc=dblarr(n/2)
				FOR i=0L, max_scan-1 DO BEGIN
					IF a8 EQ 'EV' THEN BEGIN
						IF a4 EQ 'I' THEN BEGIN
							FOR j=0L, max_frame-1 DO BEGIN
								IF dn_col_1[iham,idet,isubset,i,j,0] NE 0 THEN BEGIN
									temp[p]=dn_col_1[iham,idet,isubset,i,j,0]
									p=p+1
								ENDIF
							ENDFOR
						ENDIF
						IF a4 EQ 'M' AND dn_col_1[iham,idet,isubset,i,0,0] NE 0 THEN BEGIN
							temp[k*m:(k+1)*m-1]=dn_col_1[iham,idet,isubset,i,0:max_frame-1,0]
							k=k+1
						ENDIF
					ENDIF
					IF a8 EQ 'OB' THEN BEGIN
						IF a4 EQ 'I' THEN BEGIN
							FOR j=0L, max_frame-1 DO BEGIN
								IF dn_col_1[iham,idet,isubset,i,j,1] NE 0 THEN BEGIN
									temp_obc[p]=dn_col_1[iham,idet,isubset,i,j,1]
									p=p+1
								ENDIF
							ENDFOR
						ENDIF
						IF a4 EQ 'M' AND dn_col_1[iham,idet,isubset,i,0,1] NE 0 THEN BEGIN
							temp_obc[k*m:(k+1)*m-1]=dn_col_1[iham,idet,isubset,i,0:max_frame-1,1]
							k=k+1
						ENDIF
					ENDIF
				ENDFOR
				dn_total[iham,idet,isubset,0]=sig_mean(temp[0:n/2-1],3,1)
				std_total[iham,idet,isubset,0]=sig_mean(temp[0:n/2-1],3,2)
				dn_total[iham,idet,isubset,1]=sig_mean(temp_obc[0:n/2-1],3,1)
				std_total[iham,idet,isubset,1]=sig_mean(temp_obc[0:n/2-1],3,2)

				IF dn_total[iham,idet,isubset,0] EQ -999 THEN dn_total[iham,idet,isubset,0]=0
				IF std_total[iham,idet,isubset,0] EQ -999 THEN std_total[iham,idet,isubset,0]=0
				IF dn_total[iham,idet,isubset,1] EQ -999 THEN dn_total[iham,idet,isubset,1]=0
				IF std_total[iham,idet,isubset,1] EQ -999 THEN std_total[iham,idet,isubset,1]=0
			ENDFOR
		ENDFOR
	ENDFOR
	IF a8 EQ 'EV' THEN dn[a5,b,*,*,*,2]=dn_total[*,*,*,0]
	IF a8 EQ 'EV' THEN std[a5,b,*,*,*,2]=std_total[*,*,*,0]
	IF a8 EQ 'OB' THEN dn_obc[a5,b,*,*,*,2]=dn_total[*,*,*,1]
	IF a8 EQ 'OB' THEN std_obc[a5,b,*,*,*,2]=std_total[*,*,*,1]

;*****************************************************************************
;  Calculate drifting of dn over frames using a straight line fit.
;*****************************************************************************

	f=findgen(max_frame)
	y=dblarr(max_frame)
	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				FOR iscan=0, max_scan-1 DO BEGIN
					y[*]=dn_frame[iham,idet,isubset,iscan,*]
					result1=poly_fit(f,y,1)

					IF a8 EQ 'EV' THEN slope1[a5,b,iham,idet,isubset,iscan,*]=result1[*]
					IF a8 EQ 'OB' THEN slope_obc1[a5,b,iham,idet,isubset,iscan,*]=result1[*]
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR

;*****************************************************************************
;  Calculate drifting of dn over scans (where the dn has been frame averaged) 
;  using a straight line fit.
;*****************************************************************************

	g=findgen(max_scan)
	z=dblarr(max_scan)
	FOR iham=0, nham-1 DO BEGIN
		FOR idet=0, detectors_TEB[b]-1 DO BEGIN
			FOR isubset=0, subsets_TEB[b]-1 DO BEGIN
				z[*]=dn_col[a5,b,iham,idet,isubset,*,0]
				result2=poly_fit(g,z,1)

				IF a8 EQ 'EV' THEN slope2[a5,b,iham,idet,isubset,*]=result2[*]
				IF a8 EQ 'OB' THEN slope_obc2[a5,b,iham,idet,isubset,*]=result2[*]
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

save,/compress,dn,dn_obc,std,std_obc,slope1,slope2,slope_obc1,slope_obc2,dn_col,std_col,dn_col_2,std_col_2,filename=outfile

skipout:

END

