;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 1 test for TEB bands. Calculates the effective EV source radiance
;  and compares to specifications.
;
;  Input:
;  1) Input file with paths to RVS, and general info sav files as well
;     as the .temp.sav, .dn.sav, .rad.sav, .rg.sav, and .snr.sav files.
;
;  Output:
;    RC5 part 1.
;  1) rad_BCS_ret[collect,band,HAM,detector,subsample,ifit]
;  2) ARD[collect,band,HAM,detector,subsample,ifit]
;  3) RRU[collect,band,HAM,subsample,ifit] 
;  
;  v1.0 - 04/14/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_eff_rad, infile

;*****************************************************************************
;  Read in input file and sav TEB file.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
fnumber=strarr(1)
header_size=intarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
readf,lun,header_size
Free_Lun,lun
Free_Lun,lun

ham=initial_ham_side(inpath,header_size)

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

infname1=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
infname4=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname5=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
restore,infname1
restore,infname2
restore,infname3
restore,infname4
restore,infname5

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

outfile=outpath+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'

;*****************************************************************************
;  Find retrived BCS radiance for RC5 part 1.
;*****************************************************************************

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

fit_res=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,6)

rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,6)
delta_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,6)
mean_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)
max_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)
min_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)
std_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)

ARD=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,6)
mean_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)
max_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)
std_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)
ARD_gc=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,6)
mean_ARD_gc=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)

RRU=dblarr(ncollects,nbands_TEB,nham,maxsubsets,6)

; ifit 0-2 for linear, quadratic, and cubic with no gain correction; ifit 3-5 for linear, quadratic, and cubic with gain correction
FOR ifit=0, 5 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		FOR b=0, nbands_TEB-1 DO BEGIN
			FOR is=0, subsets_TEB[b]-1 DO BEGIN
				FOR ih=0, nham-1 DO BEGIN
					FOR id=0, detectors_TEB[b]-1 DO BEGIN
                                                IF dn[col,b,ih,id,0,0] GT dn[col,b,ih,id,1,0] AND dn_obc[col,b,ih,id,0,0] GT dn_obc[col,b,ih,id,1,0] THEN BEGIN 
                                                        isubset=is
                                                ENDIF ELSE BEGIN
                                                        IF is EQ 0 THEN isubset=1
                                                        IF is EQ 1 THEN isubset=0
                                                ENDELSE
						IF ifit EQ 0 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0]) $
							/rvs[b,is,id,ih,0]/p[b] $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 1 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0] $
							+rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,0]^2) $
							/rvs[b,is,id,ih,0]/p[b] $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 2 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0] $
							+rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,0]^2 $
							+rg_1[b,ih,id,is,3,ifit,0]*dn[col,b,ih,id,is,0]^3) $
							/rvs[b,is,id,ih,0]/p[b] $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 3 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,0,0] $
							+rg_1[b,ih,id,is,1,0,0]*dn[col,b,ih,id,is,0]) $
							/rvs[b,is,id,ih,0]/p[b]*(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)/(rg_1[b,ih,id,is,0,0,0] $
							+rg_1[b,ih,id,is,1,0,0]*dn_obc[col,b,ih,id,isubset,0])) $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 3 THEN fit_res[col,b,ih,id,is,ifit] $
							=(rad_BCS[col,b,ih,id,is,0]-rg_1[b,ih,id,is,0,0,0] $
							-rg_1[b,ih,id,is,1,0,0]*dn[col,b,ih,id,is,0]) $
							/(rad_BCS[col,b,ih,id,is,0])*100
						IF ifit EQ 4 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,1,0] $
							+rg_1[b,ih,id,is,1,1,0]*dn[col,b,ih,id,is,0] $
							+rg_1[b,ih,id,is,2,1,0]*dn[col,b,ih,id,is,0]^2) $
							/rvs[b,is,id,ih,0]/p[b]*(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)/(rg_1[b,ih,id,is,0,1,0] $
							+rg_1[b,ih,id,is,1,1,0]*dn_obc[col,b,ih,id,isubset,0] $
							+rg_1[b,ih,id,is,2,1,0]*dn_obc[col,b,ih,id,isubset,0]^2))  $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 4 THEN fit_res[col,b,ih,id,is,ifit] $
							=(rad_BCS[col,b,ih,id,is,0]-rg_1[b,ih,id,is,0,1,0] $
							-rg_1[b,ih,id,is,1,1,0]*dn[col,b,ih,id,is,0] $
							-rg_1[b,ih,id,is,2,1,0]*dn[col,b,ih,id,is,0]^2) $
							/(rad_BCS[col,b,ih,id,is,0])*100
						IF ifit EQ 5 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,2,0] $
							+rg_1[b,ih,id,is,1,2,0]*dn[col,b,ih,id,is,0] $
							+rg_1[b,ih,id,is,2,2,0]*dn[col,b,ih,id,is,0]^2 $
							+rg_1[b,ih,id,is,3,2,0]*dn[col,b,ih,id,is,0]^3) $
							/rvs[b,is,id,ih,0]/p[b]*(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)/(rg_1[b,ih,id,is,0,2,0] $
							+rg_1[b,ih,id,is,1,2,0]*dn_obc[col,b,ih,id,isubset,0] $
							+rg_1[b,ih,id,is,2,2,0]*dn_obc[col,b,ih,id,isubset,0]^2 $
							+rg_1[b,ih,id,is,3,2,0]*dn_obc[col,b,ih,id,isubset,0]^3)) $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 5 THEN fit_res[col,b,ih,id,is,ifit] $
							=(rad_BCS[col,b,ih,id,is,0]-rg_1[b,ih,id,is,0,2,0] $
							-rg_1[b,ih,id,is,1,2,0]*dn[col,b,ih,id,is,0] $
							-rg_1[b,ih,id,is,2,2,0]*dn[col,b,ih,id,is,0]^2 $
							-rg_1[b,ih,id,is,3,2,0]*dn[col,b,ih,id,is,0]^3) $
							/(rad_BCS[col,b,ih,id,is,0])*100

						ARD[col,b,ih,id,is,ifit] $
							=100*(rad_BCS_ret[col,b,ih,id,is,ifit]/rad_p1[col,b,id,0]-1)
						ARD_gc[col,b,ih,id,is,ifit]=ARD[col,b,ih,id,is,ifit]+fit_res[col,b,ih,id,is,ifit]

						delta_rad_BCS_ret[col,b,ih,id,is,ifit]=rad_BCS_ret[col,b,ih,id,is,ifit]-rad_p1[col,b,id,0]
					ENDFOR

					mean_rad_BCS_ret[col,b,ih,is,ifit] $
						=sig_mean(delta_rad_BCS_ret[col,b,ih,0:detectors_TEB[b]-1,is,ifit],3,1)
					max_rad_BCS_ret[col,b,ih,is,ifit] $
						=max(delta_rad_BCS_ret[col,b,ih,0:detectors_TEB[b]-1,is,ifit],min=min_rad)
					min_rad_BCS_ret[col,b,ih,is,ifit]=min_rad
					std_rad_BCS_ret[col,b,ih,is,ifit] $
						=sig_mean(delta_rad_BCS_ret[col,b,ih,0:detectors_TEB[b]-1,is,ifit],3,2)
					mean_ARD[col,b,ih,is,ifit] $
						=sig_mean(ARD[col,b,ih,0:detectors_TEB[b]-1,is,ifit],3,1)
					mean_ARD_gc[col,b,ih,is,ifit] $
						=sig_mean(ARD_gc[col,b,ih,0:detectors_TEB[b]-1,is,ifit],3,1)
					max_ARD[col,b,ih,is,ifit]=max(abs(ARD[col,b,ih,0:detectors_TEB[b]-1,is,ifit]))
					std_ARD[col,b,ih,is,ifit] $
						=sig_mean(ARD[col,b,ih,0:detectors_TEB[b]-1,is,ifit],3,2)

					RRU[col,b,ih,is,ifit] $
						=max(abs(delta_rad_BCS_ret[col,b,ih,0:detectors_TEB[b]-1,is,ifit] $
						-mean_rad_BCS_ret[col,b,ih,is,ifit])) $
						/(NEdT_spec[b,0]*Planck_deriv(T_typ_TEB[b,0],lambda_TEB[b]))
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Save data on ARD and RRU to dat file.
;*****************************************************************************

outfile2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.ard.txt'
outfile3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.ard.gc.txt'
outfile4=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rru.txt'
outfile5=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rru.gc.txt'

fmt_1='(i2, 5x, i3, 5x, i2, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f)'

openw,lun,outfile2,/get_lun
printf,lun,'Worst case Absolute Radiance Difference (ARD) no gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(max_ARD[col,0,ih,*,1]),mean(max_ARD[col,1,ih,*,1]), $
			max_ARD[col,2,ih,0,1],max_ARD[col,3,ih,0,1],max_ARD[col,4,ih,0,1], $
			max_ARD[col,5,ih,0,1],max_ARD[col,6,ih,0,1],max_ARD[col,7,ih,0,1]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile3,/get_lun
printf,lun,'Worst case Absolute Radiance Difference (ARD) gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(max_ARD[col,0,ih,*,4]),mean(max_ARD[col,1,ih,*,4]), $
			max_ARD[col,2,ih,0,4],max_ARD[col,3,ih,0,4],max_ARD[col,4,ih,0,4], $
			max_ARD[col,5,ih,0,4],max_ARD[col,6,ih,0,4],max_ARD[col,7,ih,0,4]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile4,/get_lun
printf,lun,'Worst case Relative Response Uniformity (RRU) no gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(RRU[col,0,ih,*,1]),mean(RRU[col,1,ih,*,1]), $
			RRU[col,2,ih,0,1],RRU[col,3,ih,0,1],RRU[col,4,ih,0,1], $
			RRU[col,5,ih,0,1],RRU[col,6,ih,0,1],RRU[col,7,ih,0,1]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile5,/get_lun
printf,lun,'Worst case Relative Response Uniformity (RRU) gain correction'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(RRU[col,0,ih,*,4]),mean(RRU[col,1,ih,*,4]), $
			RRU[col,2,ih,0,4],RRU[col,3,ih,0,4],RRU[col,4,ih,0,4], $
			RRU[col,5,ih,0,4],RRU[col,6,ih,0,4],RRU[col,7,ih,0,4]
	ENDFOR
ENDFOR
free_lun,lun
close,lun,/file,/all

save,/compress,rad_BCS_ret,ARD,ARD_gc,max_ARD,mean_ARD,mean_ARD,RRU,filename=outfile

END
