;*****************************************************************************
;				NICST TOOL
;
;  RC-5 Part 1 test for TEB bands. Calculates the effective EV source radiance
;  and compares to specifications.
;
;  Input:
;  1) Input file with paths to RVS, and general info sav files as well
;     as the .temp.sav, .dn.sav, .rad.sav, .rg.sav, and .snr.sav files.
;
;  Output:
;    RC5 part 1.
;  1) rad_BCS_ret[collect,band,HAM,detector,subsample,ifit]
;  2) ARD[collect,band,HAM,detector,subsample,ifit]
;  3) RRU[collect,band,HAM,subsample,ifit] 
;  
;  v1.0 - 04/14/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_gain_correction, infile

;*****************************************************************************
;  Read in input file and sav TEB file.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
fnumber=strarr(1)
header_size=intarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
readf,lun,header_size
Free_Lun,lun
Free_Lun,lun

ham=initial_ham_side(inpath,header_size)

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

infname1=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
infname4=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname5=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
restore,infname1
restore,infname2
restore,infname3
restore,infname4
restore,infname5

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

outfile=outpath+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'

;*****************************************************************************
;  Find retrived BCS radiance for RC5 part 1.
;*****************************************************************************

NEDT_spec=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

mindet=[0,0,0,0,1,0,0,0]

rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
delta_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
ARD=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
mean_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
max_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
min_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
std_rad_BCS_ret=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
mean_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
max_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
std_ARD=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)
RRU=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)

ARD_gc=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
fit_res=dblarr(ncollects,nbands_TEB,nham,maxdet,maxsubsets,3)
mean_ARD_gc=dblarr(ncollects,nbands_TEB,nham,maxsubsets,3)

FOR ifit=0, 2 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		FOR b=0, nbands_TEB-1 DO BEGIN
			FOR is=0, subsets_TEB[b]-1 DO BEGIN
				FOR ih=0, nham-1 DO BEGIN
					FOR id=0, detectors_TEB[b]-1 DO BEGIN
						IF ifit EQ 0 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0]) $
							/0.4444/rvs[b,is,id,ih,0] $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
                                                IF dn[col,b,ih,id,0,0] GT dn[col,b,ih,id,1,0] AND dn_obc[col,b,ih,id,0,0] GT dn_obc[col,b,ih,id,1,0] THEN BEGIN 
                                                        isubset=is
                                                ENDIF ELSE BEGIN
                                                        IF is EQ 0 THEN isubset=1
                                                        IF is EQ 1 THEN isubset=0
                                                ENDELSE
						IF ifit EQ 1 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0] $
							+rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,0]^2) $
							/0.4444/rvs[b,is,id,ih,0]*(sig_mean(rad_OBC[col,b,ih,id,is,0:99],3,1)*0.4444/(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn_obc[col,b,ih,id,isubset,0] $
							+rg_1[b,ih,id,is,2,ifit,0]*dn_obc[col,b,ih,id,isubset,0]^2))  $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])
						IF ifit EQ 1 THEN fit_res[col,b,ih,id,is,ifit] $
							=(rad_BCS[col,b,ih,id,is,0]*0.4444-rg_1[b,ih,id,is,0,ifit,0] $
							-rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0] $
							-rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,0]^2) $
							/(rad_BCS[col,b,ih,id,is,0]*0.4444)*100
						IF ifit EQ 2 THEN rad_BCS_ret[col,b,ih,id,is,ifit] $
							=(rg_1[b,ih,id,is,0,ifit,0] $
							+rg_1[b,ih,id,is,1,ifit,0]*dn[col,b,ih,id,is,0] $
							+rg_1[b,ih,id,is,2,ifit,0]*dn[col,b,ih,id,is,0]^2 $
							+rg_1[b,ih,id,is,3,ifit,0]*dn[col,b,ih,id,is,0]^3) $
							/0.4444/rvs[b,is,id,ih,0] $
							+(rvs[b,is,id,ih,1]/rvs[b,is,id,ih,0])*rad_p1[col,b,id,1] $
							-(rvs[b,is,id,ih,1]-rvs[b,is,id,ih,0])/(rvs[b,is,id,ih,0]*p[b]) $
							*(rad_p2[col,b,ih,id,0]-(1-p[b])*rad_p2[col,b,ih,id,1])

						delta_rad_BCS_ret[col,b,ih,id,is,ifit] $
							=rad_BCS_ret[col,b,ih,id,is,ifit]-rad_p1[col,b,id,0]

						ARD[col,b,ih,id,is,ifit] $
							=100*(rad_BCS_ret[col,b,ih,id,is,ifit]/rad_p1[col,b,id,0]-1)
						IF ifit EQ 1 THEN ARD_gc[col,b,ih,id,is,ifit]=ARD[col,b,ih,id,is,ifit]+fit_res[col,b,ih,id,is,ifit]
					ENDFOR

					mean_rad_BCS_ret[col,b,ih,is,ifit] $
						=sig_mean(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit],3,1)
					max_rad_BCS_ret[col,b,ih,is,ifit] $
						=max(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit],min=min_rad)
					min_rad_BCS_ret[col,b,ih,is,ifit]=min_rad
					std_rad_BCS_ret[col,b,ih,is,ifit] $
						=sig_mean(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit],3,2)
					mean_ARD[col,b,ih,is,ifit] $
						=sig_mean(ARD[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit],3,1)
					mean_ARD_gc[col,b,ih,is,ifit] $
						=sig_mean(ARD_gc[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit],3,1)
					max_ARD[col,b,ih,is,ifit]=max(abs(ARD[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit]))
					std_ARD[col,b,ih,is,ifit] $
						=sig_mean(ARD[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit],3,2)

					RRU[col,b,ih,is,ifit] $
						=max(abs(delta_rad_BCS_ret[col,b,ih,mindet[b]:detectors_TEB[b]-1,is,ifit] $
						-mean_rad_BCS_ret[col,b,ih,is,ifit])) $
						/(NEdT_spec[b,0]*Planck_deriv(T_typ_TEB[b,0],lambda_TEB[b]))
				ENDFOR
			ENDFOR
		ENDFOR
	ENDFOR
ENDFOR

;*****************************************************************************
;  Save data on ARD and RRU to dat file.
;*****************************************************************************

outfile2=outpath+a2[a3-2]+'.'+a2[a3-1]+'.ard_temp.txt'
outfile3=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rru_temp.txt'

fmt_1='(i2, 5x, i3, 5x, i2, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f, 5x, f)'

openw,lun,outfile2,/get_lun
printf,lun,'Absolute Radiance Difference (ARD)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(max_ARD[col,0,ih,*,1]),mean(max_ARD[col,1,ih,*,1]), $
			max_ARD[col,2,ih,0,1],max_ARD[col,3,ih,0,1],max_ARD[col,4,ih,0,1], $
			max_ARD[col,5,ih,0,1],max_ARD[col,6,ih,0,1],max_ARD[col,7,ih,0,1]
	ENDFOR
ENDFOR
free_lun,lun

openw,lun,outfile3,/get_lun
printf,lun,'Relative Response Uniformity (RRU)'
printf,lun,'Collect     Temp       HAM      I4        I5       M12       M13        M14      M15      M16A      M16B'
FOR ih=0, nham-1 DO BEGIN
	FOR col=0, ncollects-1 DO BEGIN
		printf,lun,format=fmt_1,col,T_bcs[col],ih,mean(RRU[col,0,ih,*,1]),mean(RRU[col,1,ih,*,1]), $
			RRU[col,2,ih,0,1],RRU[col,3,ih,0,1],RRU[col,4,ih,0,1], $
			RRU[col,5,ih,0,1],RRU[col,6,ih,0,1],RRU[col,7,ih,0,1]
	ENDFOR
ENDFOR
free_lun,lun
close,lun,/file,/all

save,/compress,rad_BCS_ret,ARD,max_ARD,RRU,filename=outfile

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.ard.gain_correction.ps'
device,/landscape,filename=outfname,/color
!p.multi=[0,1,1]
!p.position=0

G=findgen(30)
FOR b=0, nbands_TEB-1 DO BEGIN
	title1='Absolute Radiance Difference, (SRV0545)'
	title2=band_name_TEB[b]+' (quadratic poly_fit)'

	ymax=max(ARD[0:ncollects-1,b,0,0:detectors_TEB[b]-1,0,1],min=ymin)

	plot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,0,0,0,1],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-1,1], $
		xrange=[220,360],title=title2,charsize=1.2,charthick=5,/nodata

	FOR id=0,detectors_TEB[b]-1 DO BEGIN
		oplot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,0,id,0,1],symsize=1,color=lcol[id],psym=symbol[id]
		oplot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,0,id,0,1],color=lcol[id]
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
	IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
	IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

plot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,0,0,0,1],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-1,1], $
	xrange=[225,350],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands_TEB-1 DO BEGIN
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,b,0,0,1],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,b,0,0,1],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name_TEB,lcol,symbol

plot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,0,0,0,1],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-1,1], $
	xrange=[225,350],charsize=1.2,charthick=5,/nodata
FOR b=0, nbands_TEB-1 DO BEGIN
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,b,0,0,1],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,b,0,0,1],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name_TEB,lcol,symbol

device,/close

END
