;*****************************************************************************
;  RC5 Part 1 graphs of the specifications.
;  
;  Output:
;  1) postscript file containing graphs.
;
;  v1.0 - 04/18/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_view_req, infile

close,/all

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
fnumber=fltarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.req.ps'
device,/landscape,filename=outfname,/color

infname=strarr(6)
infname[0]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rad.sav'
infname[1]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.dn.sav'
infname[2]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.rg.sav'
infname[3]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.snr.sav'
infname[4]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.eff_rad.sav'
infname[5]=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
check=FILE_SEARCH(infname[0])
IF check EQ '' THEN BEGIN
	print,'No file is found.',infname[0]
	goto,skip_loop
ENDIF
FOR i=0, 5 DO BEGIN
	print,'Processing file:',infname[i]
	restore,infname[i]
ENDFOR

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)

;*****************************************************************************
;  Radiometric response characterization uncertainty (RRCU) (SRV0448).
;*****************************************************************************

!p.multi=[0,2,1]
title=strarr(2)

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	E=findgen(detectors_TEB[b])

	title1='RRCU vs Detector (SRV0448)'
	IF band_type_TEB[b] EQ 0 THEN name=[band_name_TEB[b]+' quad',band_name_TEB[b]+' cubic','Spec']
	IF band_type_TEB[b] EQ 1 THEN name=[band_name_TEB[b]+' SS1 quad',band_name_TEB[b]+' SS1 cubic', $
		band_name_TEB[b]+' SS2 quad',band_name_TEB[b]+' SS2 cubic','Spec']

	FOR ih=0, nham-1 DO BEGIN
		title2=band_name_TEB[b]+', '+'HAM='+strtrim(string(ih+1),2)

		ymax=max(rrcu[b,*,1:detectors_TEB[b]-1,*,*,0,0])
		IF ymax LT 0.001 THEN ymax=0.0011
		plot,E[*]+1,rrcu[b,0,*,0,1,0,0],xtit='Detectors',ytit='RRCU',yrange=[0,ymax],title=title2, $
			charsize=1.2,charthick=5,/nodata

		j=0
		FOR is=0, subsets_TEB[b]-1 DO BEGIN
			FOR ifit=1, 2 DO BEGIN
				oplot,E[*]+1,rrcu[b,ih,*,is,ifit,0,0],symsize=1,color=lcol[j],psym=symbol[j]
				oplot,E[*]+1,rrcu[b,ih,*,is,ifit,0,0],color=lcol[j]
				j=j+1
			ENDFOR
		ENDFOR
		oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=1.5
			
		XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

		IF band_type_TEB[b] EQ 0 THEN legend,name,linestyle=[0,0,1],colors=[0,1,1],thick=2,charthick=5,/right_legend
		IF band_type_TEB[b] EQ 1 THEN legend,name,linestyle=[0,0,0,0,1],colors=[0,1,2,3,1],thick=2, $
			charthick=5,/right_legend
	ENDFOR
ENDFOR

!p.multi=[0,2,2]
title=strarr(2)

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	E=findgen(detectors_TEB[b])

	title1='RRCU vs Detector (SRV0448)'

	title2=band_name_TEB[b]+', HAM=A'

	ymax=max(rrcu[b,*,1:detectors_TEB[b]-1,*,*,0,0])
	IF b EQ 4 THEN ymax=0.01
	plot,E[*]+1,rrcu[b,0,*,0,1,0,0],xtit='Detectors',ytit='RRCU',yrange=[0,ymax],title=title2, $
		charsize=1.2,charthick=5,/nodata

	j=0
	FOR ifit=1, 2 DO BEGIN
		oplot,E[*]+1,rrcu[b,0,*,0,ifit,0,0],symsize=1,color=lcol[j],psym=symbol[j]
		oplot,E[*]+1,rrcu[b,0,*,0,ifit,0,0],color=lcol[j]
		j=j+1
	ENDFOR
	oplot,[0,100],[0.001,0.001],color=lcol[1],linestyle=2,thick=1.5
			
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

;*****************************************************************************
;  Radiometric response non-linearity (RRNL) (SRV0595).
;*****************************************************************************

!p.multi=[0,1,1]

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.position=0

	E=findgen(detectors_TEB[b])
	title1='RRNL vs Detector (SRV0595)'
	title2=band_name_TEB[b]+' (linear poly_fit)'

	IF band_type_TEB[b] EQ 0 THEN name=[band_name_TEB[b]+' HAM A',band_name_TEB[b]+' HAM B','Spec']
	IF band_type_TEB[b] EQ 1 THEN name=[band_name_TEB[b]+' SS1 HAM A',band_name_TEB[b]+' SS1 HAM B', $
		band_name_TEB[b]+' SS2 HAM A',band_name_TEB[b]+' SS2 HAM B','Spec']

	ymax=max(rrnl[b,*,*,*,3,0])
	IF ymax LT 0.01 AND band_type_TEB[b] EQ 0 THEN ymax=0.011
	IF ymax LT 0.01 AND band_type_TEB[b] EQ 1 THEN ymax=0.013

	plot,E[*]+1,rrnl[b,0,*,0,3,0],xtit='Detectors',ytit='RRNL',yrange=[0,ymax],title=title2,charsize=1.2,charthick=5,/nodata

	j=0
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			oplot,E[*]+1,rrnl[b,ih,*,is,3,0],symsize=1,color=lcol[j],psym=symbol[j]
			oplot,E[*]+1,rrnl[b,ih,*,is,3,0],color=lcol[j]
			j=j+1
		ENDFOR
	ENDFOR
	oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=1.5

	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

	IF band_type_TEB[b] EQ 0 THEN legend,name,linestyle=[0,0,1],colors=[0,1,1],thick=2,charthick=5,/right_legend
	IF band_type_TEB[b] EQ 1 THEN legend,name,linestyle=[0,0,0,0,1],colors=[0,1,2,3,1],thick=2,charthick=5,/right_legend
ENDFOR

!p.multi=[0,2,2]
!p.position=0

FOR b=0, nbands_TEB-1 DO BEGIN
	E=findgen(detectors_TEB[b])
	title1='RRNL vs Detector (SRV0595)'
	title2=band_name_TEB[b]+' (linear poly_fit)'

	ymax=max(rrnl[b,*,*,*,3,0])
	IF ymax LT 0.01 AND band_type_TEB[b] EQ 0 THEN ymax=0.011
	IF ymax LT 0.01 AND band_type_TEB[b] EQ 1 THEN ymax=0.013

	plot,E[*]+1,rrnl[b,0,*,0,3,0],xtit='Detectors',ytit='RRNL',yrange=[0,ymax],title=title2,charsize=1.2,charthick=5,/nodata

	oplot,E[*]+1,rrnl[b,0,*,0,3,0],symsize=1,color=lcol[1],psym=symbol[1]
	oplot,E[*]+1,rrnl[b,0,*,0,3,0],color=lcol[1]

	oplot,[0,100],[0.01,0.01],color=lcol[1],linestyle=2,thick=1.5

	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

;*****************************************************************************
;  NEdT at T_typ (SRV0053).
;*****************************************************************************

NEdT_typ_req=[[2.5,1.5,0.396,0.107,0.091,0.07,0.072,0.072],[0,0,0,0.423,0,0,0,0]]

!p.multi=[0,1,1]
!p.position=0

FOR b=0, nbands_TEB-1 DO BEGIN

	G=findgen(detectors_TEB[b])

	title1='NEdT at T_typ (SRV0053)'
	title2=band_name_TEB[b]

	IF band_type_TEB[b] EQ 0 THEN name=[band_name_TEB[b]+' HAM A',band_name_TEB[b]+' HAM B','Spec']
	IF band_type_TEB[b] EQ 1 THEN name=[band_name_TEB[b]+' SS1 HAM A',band_name_TEB[b]+' SS1 HAM B', $
		band_name_TEB[b]+' SS2 HAM A',band_name_TEB[b]+' SS2 HAM B','Spec']

	plot,G[*]+1,NEdT_typ[b,0,*,0,0,1,0],xtit='Detectors',ytit='NEdT',yrange=[0,NEdT_typ_req[b]*1.3], $
		xrange=[0,detectors_TEB[b]],title=title2,charsize=1.2,charthick=5,/nodata

	j=0
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			oplot,G[*]+1,NEdT_typ[b,ih,*,is,0,1,0],symsize=1,color=lcol[j],psym=symbol[j]
			oplot,G[*]+1,NEdT_typ[b,ih,*,is,0,1,0],color=lcol[j]
			j=j+1
		ENDFOR
	ENDFOR
	oplot,[0,50],[NEdT_typ_req[b,0],NEdT_typ_req[b,0]],symsize=1,color=lcol[1],linestyle=2,thick=1.5

	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

	IF band_type_TEB[b] EQ 0 THEN legend,name,linestyle=[0,0,1],colors=[0,1,1],thick=2,charthick=5,/right_legend
	IF band_type_TEB[b] EQ 1 THEN legend,name,linestyle=[0,0,0,0,1],colors=[0,1,2,3,1],thick=2,charthick=5,/right_legend
ENDFOR

;*****************************************************************************
;  Absolute Radiance Difference (SRV0545 and SRV0546).
;*****************************************************************************

FOR col=0, ncollects-1 DO BEGIN
	IF col GT 0 AND col LT ncollects-1 THEN BEGIN
		IF abs(T_bcs[col-1]-267) GT abs(T_bcs[col]-267) AND abs(T_bcs[col]-267) LT abs(T_bcs[col+1]-267) THEN BEGIN
			col_267=col
		ENDIF
		IF abs(T_bcs[col-1]-230) GT abs(T_bcs[col]-230) AND abs(T_bcs[col]-230) LT abs(T_bcs[col+1]-230) THEN BEGIN
			col_230=col
		ENDIF
		IF abs(T_bcs[col-1]-270) GT abs(T_bcs[col]-270) AND abs(T_bcs[col]-270) LT abs(T_bcs[col+1]-270) THEN BEGIN
			col_270=col
		ENDIF
		IF abs(T_bcs[col-1]-310) GT abs(T_bcs[col]-310) AND abs(T_bcs[col]-310) LT abs(T_bcs[col+1]-310) THEN BEGIN
			col_310=col
		ENDIF
	ENDIF
ENDFOR
col_190=0
col_340=ncollects-1
x=min(T_bcs[*])
IF x GT 200 THEN col_190=-1
IF x GT 240 THEN col_230=-1
scol=[col_190,col_230,col_270,col_310,col_340]

ARD_req_I=[5,2.5]
ARD_req_M=[[0,0,12.3,2.1,1.6,1.6],[7.0,5.7,2.4,0.60,.60,.60],[0.7,0.7,0.6,0.4,0.4,0.4], $
	[0.7,0.7,0.4,0.4,0.4,0.4],[0.7,0.7,0.5,0.4,0.4,0.4]]
collect_name=['190','230','270','310','340']

G=findgen(detectors_TEB[0])
FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 0 THEN goto,skipi
	!p.multi=[0,1,1]
	!p.position=0

	name=[band_name_TEB[b]+' SS1 HAM A',band_name_TEB[b]+' SS1 HAM B', $
		band_name_TEB[b]+' SS2 HAM A',band_name_TEB[b]+' SS2 HAM B','Spec']

	title1='Absolute Radiance Difference, T_bcs=267 (SRV0546)'
	title2=band_name_TEB[b]+' (quadratic poly_fit)'

	plot,G[*]+1,ARD[col_267,b,0,*,0,1],xtit='Detectors',ytit='ARD',yrange=[-ARD_req_I[b]-1,ARD_req_I[b]+2], $
		xrange=[0,detectors_TEB[b]],title=title2,charsize=1.2,charthick=5,/nodata

	j=0
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			oplot,G[*]+1,ARD[col_267,b,ih,*,is,1],symsize=1,color=lcol[j],psym=symbol[j]
			oplot,G[*]+1,ARD[col_267,b,ih,*,is,1],color=lcol[j]
			oplot,[0,50],[ARD_req_I[b],ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
			oplot,[0,50],[-ARD_req_I[b],-ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
			j=j+1
		ENDFOR
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
	legend,name,linestyle=[0,0,0,0,1],colors=[0,1,2,3,1],thick=2,charthick=5,/right_legend

	skipi:
ENDFOR

FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 0 THEN goto,skipi2
	!p.multi=[0,1,1]
	!p.position=0

	title1='Absolute Radiance Difference, T_bcs=267 (SRV0546)'
	title2=band_name_TEB[b]+' (quadratic poly_fit)'

	plot,G[*]+1,abs(ARD[col_267,b,0,*,0,1]),xtit='Detectors',ytit='ARD',yrange=[0,ARD_req_I[b]+2], $
		xrange=[0,detectors_TEB[b]],title=title2,charsize=1.2,charthick=5,/nodata

	oplot,G[*]+1,abs(ARD[col_267,b,0,*,0,1]),symsize=1,color=lcol[1],psym=symbol[1]
	oplot,G[*]+1,abs(ARD[col_267,b,0,*,0,1]),color=lcol[1]
	oplot,[0,50],[ARD_req_I[b],ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
	oplot,[0,50],[-ARD_req_I[b],-ARD_req_I[b]],symsize=1,color=lcol[1],linestyle=2,thick=1.5

	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

	skipi2:
ENDFOR


G=findgen(detectors_TEB[2])
FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 1 THEN goto,skipm

	!p.multi=[0,3,2]
	!p.position=0

	name=[band_name_TEB[b]+' HAM A',band_name_TEB[b]+' HAM B','Spec']

	k=0
	FOR j=0, 4 DO BEGIN
		IF scol[j] LT 0 THEN continue

		title1='Absolute Radiance Difference, T='+collect_name[j]+' (SRV0545)'
		title2=band_name_TEB[b]+', T='+collect_name[j]+' (quadratic poly_fit)'

		ymax=max(ARD[scol[j],b,*,*,0,1],min=ymin)
		IF ymax LT ARD_req_M[b-2,j] THEN ymax=ARD_req_M[b-2,j]*(1.1)
		IF ymin GT -ARD_req_M[b-2,j] THEN ymin=-ARD_req_M[b-2,j]*(1.1)

		plot,G[*]+1,ARD[scol[j],b,0,*,0,1],xtit='Detectors',ytit='ARD',yrange=[ymin,ymax], $
			xrange=[0,detectors_TEB[b]],title=title2,charsize=1.2,charthick=5,/nodata

		FOR ih=0, nham-1 DO BEGIN
			oplot,G[*]+1,ARD[scol[j],b,ih,*,0,1],symsize=1,color=lcol[k],psym=symbol[k]
			oplot,G[*]+1,ARD[scol[j],b,ih,*,0,1],color=lcol[k]
			oplot,[0,50],[ARD_req_M[b-2,j],ARD_req_M[b-2,j]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
			oplot,[0,50],[-ARD_req_M[b-2,j],-ARD_req_M[b-2,j]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
			k=k+1
		ENDFOR
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
	legend,name,linestyle=[0,0,1],colors=[0,1,1],thick=2,charthick=5,/right_legend

	skipm:
ENDFOR

FOR b=0, nbands_TEB-1 DO BEGIN
	IF band_type_TEB[b] EQ 1 THEN goto,skipm2

	!p.multi=[0,3,2]
	!p.position=0

	k=0
	FOR j=0, 4 DO BEGIN
		IF scol[j] LT 0 THEN continue

		title1='Absolute Radiance Difference, T='+collect_name[j]+' (SRV0545)'
		title2=band_name_TEB[b]+', T='+collect_name[j]+' (quadratic poly_fit)'

		ymax=max(ARD[scol[j],b,*,*,0,1],min=ymin)
		IF ymax LT ARD_req_M[b-2,j] THEN ymax=ARD_req_M[b-2,j]*(1.1)

		plot,G[*]+1,abs(ARD[scol[j],b,0,*,0,1]),xtit='Detectors',ytit='ARD',yrange=[0,ymax], $
			xrange=[0,detectors_TEB[b]],title=title2,charsize=1.2,charthick=5,/nodata

		oplot,G[*]+1,abs(ARD[scol[j],b,0,*,0,1]),symsize=1,color=lcol[k],psym=symbol[k]
		oplot,G[*]+1,abs(ARD[scol[j],b,0,*,0,1]),color=lcol[k]
		oplot,[0,50],[ARD_req_M[b-2,j],ARD_req_M[b-2,j]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
		oplot,[0,50],[-ARD_req_M[b-2,j],-ARD_req_M[b-2,j]],symsize=1,color=lcol[1],linestyle=2,thick=1.5
		k=k+1
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5

	skipm2:
ENDFOR

!p.multi=[0,1,1]
!p.position=0

G=findgen(30)
FOR b=0, nbands_TEB-1 DO BEGIN
	title1='Absolute Radiance Difference, (SRV0545)'
	title2=band_name_TEB[b]+' (quadratic poly_fit) HAM A'

	ymax=max(ARD[0:ncollects-1,b,0,0:detectors_TEB[b]-1,0,4],min=ymin)

	plot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,0,0,0,4],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-2,2], $
		xrange=[220,360],title=title2,charsize=1.2,charthick=5,/nodata

	FOR id=0,detectors_TEB[b]-1 DO BEGIN
		oplot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,0,id,0,4],symsize=1,color=lcol[id],psym=symbol[id]
		oplot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,0,id,0,4],color=lcol[id]
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
	IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
	IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR
FOR b=0, nbands_TEB-1 DO BEGIN
	title1='Absolute Radiance Difference, (SRV0545)'
	title2=band_name_TEB[b]+' (quadratic poly_fit) HAM B'

	ymax=max(ARD[0:ncollects-1,b,1,0:detectors_TEB[b]-1,0,4],min=ymin)

	plot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,1,0,0,4],xtit='BCS Temperature (K)',ytit='ARD',yrange=[-2,2], $
		xrange=[220,360],title=title2,charsize=1.2,charthick=5,/nodata

	FOR id=0,detectors_TEB[b]-1 DO BEGIN
		oplot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,1,id,0,4],symsize=1,color=lcol[id],psym=symbol[id]
		oplot,T_bcs[0:ncollects-1]+1,ARD[0:ncollects-1,b,1,id,0,4],color=lcol[id]
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
	IF band_type_TEB[b] EQ 0 THEN set_legend,1,chname,lcol,symbol
	IF band_type_TEB[b] EQ 1 THEN set_legend,2,chname,lcol,symbol
ENDFOR

title2='HAM A'
plot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,0,0,0,4],xtit='BCS Temperature (K)',ytit='Mean ARD',yrange=[-2,2], $
	xrange=[225,350],title=title2,charsize=1.2,charthick=5,/nodata
FOR b=0, nbands_TEB-1 DO BEGIN
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,b,0,0,4],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,b,0,0,4],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name_TEB,lcol,symbol

plot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,0,0,0,4],xtit='BCS Temperature (K)',ytit='Mean ARD',yrange=[-2,2], $
	xrange=[225,350],title=title2,charsize=1.2,charthick=5,/nodata
FOR b=0, nbands_TEB-1 DO BEGIN
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,b,0,0,4],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,b,0,0,4],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name_TEB,lcol,symbol

title2='HAM B'
plot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,1,0,0,4],xtit='BCS Temperature (K)',ytit='Mean ARD',yrange=[-2,2], $
	xrange=[225,350],title=title2,charsize=1.2,charthick=5,/nodata
FOR b=0, nbands_TEB-1 DO BEGIN
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,b,1,0,4],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD[0:ncollects-1,b,1,0,4],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name_TEB,lcol,symbol

plot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,0,1,0,4],xtit='BCS Temperature (K)',ytit='Mean ARD',yrange=[-2,2], $
	xrange=[225,350],title=title2,charsize=1.2,charthick=5,/nodata
FOR b=0, nbands_TEB-1 DO BEGIN
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,b,1,0,4],symsize=1,color=lcol[b],psym=symbol[b]
	oplot,T_bcs[0:ncollects-1]+1,mean_ARD_gc[0:ncollects-1,b,1,0,4],color=lcol[b]
ENDFOR
XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
set_legend,1,band_name_TEB,lcol,symbol

;*****************************************************************************
;  RRU (SRV0613).
;*****************************************************************************

H=findgen(ncollects)

FOR b=0, nbands_TEB-1 DO BEGIN
	!p.multi=[0,1,1]
	!p.position=0

	title1='RRU (SRV0613)'
	IF b NE 2 AND b NE 3 THEN title2=band_name_TEB[b]+' (quadratic poly_fit)'
	IF b EQ 2 OR b EQ 3 THEN title2=band_name_TEB[b]+' (cubic poly_fit)'

	IF b NE 2 AND b NE 3 THEN ifit=1
	IF b EQ 2 OR b EQ 3 OR b EQ 4 THEN ifit=2

	IF band_type_TEB[b] EQ 0 THEN name=[band_name_TEB[b]+' HAM A',band_name_TEB[b]+' HAM B','Spec']
	IF band_type_TEB[b] EQ 1 THEN name=[band_name_TEB[b]+' SS1 HAM A',band_name_TEB[b]+' SS1 HAM B', $
		band_name_TEB[b]+' SS2 HAM A',band_name_TEB[b]+' SS2 HAM B','Spec']

	ymax=max(RRU[*,b,0,0,ifit])
	IF ymax LT 1. THEN ymax=1.1
	plot,H[*]+1,RRU[*,b,0,0,0,0],xtit='Collects',ytit='RRU',yrange=[0,ymax],xrange=[0,ncollects], $
		title=title2,charsize=1.2,charthick=5,/nodata

	j=0
	FOR is=0, subsets_TEB[b]-1 DO BEGIN
		FOR ih=0, nham-1 DO BEGIN
			oplot,H[*]+1,RRU[*,b,ih,is,ifit],symsize=1,color=lcol[j],psym=symbol[j]
			oplot,H[*]+1,RRU[*,b,ih,is,ifit],color=lcol[j]
			oplot,[0,1000],[1.,1.],symsize=1,color=lcol[1],linestyle=2,thick=1.5
			j=j+1
		ENDFOR
	ENDFOR
	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
	IF band_type_TEB[b] EQ 0 THEN legend,name,linestyle=[0,0,1],colors=[0,1,1],thick=2,charthick=5,/right_legend
	IF band_type_TEB[b] EQ 1 THEN legend,name,linestyle=[0,0,0,0,1],colors=[0,1,2,3,1],thick=2,charthick=5,/right_legend
ENDFOR

!p.multi=[0,2,2]
!p.position=0

FOR b=0, nbands_TEB-1 DO BEGIN
	title1='RRU (SRV0613)'
	title2=band_name_TEB[b]+' (quadratic poly_fit)'

	ifit=1

	ymax=max(RRU[*,b,0,0,ifit])
	IF ymax LT 1. THEN ymax=1.1
	plot,T_bcs[*],RRU[*,b,0,0,0,0],xtit='T_bcs (K)',ytit='RRU',yrange=[0,ymax],xrange=[min(T_bcs[*]),max(T_bcs[*])], $
		title=title2,charsize=1.2,charthick=5,/nodata

	oplot,T_bcs[*],RRU[*,b,0,0,ifit],symsize=1,color=lcol[1],psym=symbol[1]
	oplot,T_bcs[*],RRU[*,b,0,0,ifit],color=lcol[1]
	oplot,[0,1000],[1.,1.],symsize=1,color=lcol[1],linestyle=2,thick=1.5

	XYOUTS,0.5,1.025,title1,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

device,/close

skip_loop:

END
