;*****************************************************************************
;  RC5 Part 1 graphs of the temperatures.
;  
;  Output:
;  1) postscript file containing graphs.
;
;  v1.0 - 04/18/2008 - Jeff McIntire
;*****************************************************************************

PRO RC5_view_temp, infile

close,/all

restore,'/home/jmcintire/VIIRS_Data/general.TEB.sav'

;*****************************************************************************
;  Read in data.
;*****************************************************************************

nlines=File_Lines(infile)
ab=''
header=strarr(1)
inpath=strarr(1)		; Input path.
outpath=strarr(1)		; Output path.
rvs_in=strarr(1)
param_in=strarr(1)
rsrpath=strarr(1)
fnumber=fltarr(1)
header_size=intarr(1)

openr,lun,infile,/Get_Lun	
readf,lun,header	
readf,lun,inpath
readf,lun,outpath
readf,lun,rvs_in
readf,lun,param_in
readf,lun,rsrpath
readf,lun,fnumber
readf,lun,header_size
Free_Lun,lun

a2=strsplit(outpath,'/',/Extract)
a3=N_ELEMENTS(a2)

set_multicolor,xsave,ysave,psave,chname,lcol,symbol,red,green,blue
set_plot,'ps'
outfname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.ps'
device,/landscape,filename=outfname,/color

infname=outpath+a2[a3-2]+'.'+a2[a3-1]+'.temp.sav'
print,'Processing file:',infname
restore,infname

n_collect,inpath,ncollects,type,0
ham=initial_ham_side(inpath,header_size)

maxscans=100

D=findgen(4000)
E=findgen(30000)
F=fltarr(30000)

;*****************************************************************************
;  OBC temperature over scans.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='T_obc vs Scan and Collect for HAM A'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_obc',yrange=[T_obc[0,0]-0.5,T_obc[0,0]+0.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_obc_2[0:maxscans-1,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='T_obc vs Scan and Collect for HAM B'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_obc',yrange=[T_obc[0,0]-0.5,T_obc[0,0]+0.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_obc_2[0:maxscans-1,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_obc vs Scan, HAM=A'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_obc_2[*,0,col])
	plot,T_obc_2[*,0,col],xtit='Scan',ytit='T_obc',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_obc_2[*,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_obc vs Scan, HAM=B'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_obc_2[*,0,col])
	plot,T_obc_2[*,1,col],xtit='Scan',ytit='T_obc',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_obc_2[*,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_obc vs Scan: Collect='+strtrim(string(col+1),2)
	FOR ih=0, nham-1 DO BEGIN
		title1='HAM='+strtrim(string(ih+1),2)

		ymax=max(T_obc_2[*,ih,col])
		plot,T_obc_2[*,ih,col],xtit='Scan',ytit='T_obc',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

		oplot,T_obc_2[*,ih,col],symsize=1,color=lcol[col],psym=symbol[col]
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
ENDFOR

;*****************************************************************************
;  CAV temperature over scans.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='T_cav vs Scan and Collect for HAM A'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_cav',yrange=[T_cav[0,0]-1.5,T_cav[0,0]+1.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_cav_2[0:maxscans-1,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='T_cav vs Scan and Collect for HAM B'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_cav',yrange=[T_cav[0,0]-1.5,T_cav[0,0]+1.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_cav_2[0:maxscans-1,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_cav vs Scan, HAM=A'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_cav_2[*,0,col])
	plot,T_cav_2[*,0,col],xtit='Scan',ytit='T_cav',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_cav_2[*,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_cav vs Scan, HAM=B'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_cav_2[*,0,col])
	plot,T_cav_2[*,1,col],xtit='Scan',ytit='T_cav',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_cav_2[*,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_cav vs Scan: Collect='+strtrim(string(col+1),2)
	FOR ih=0, nham-1 DO BEGIN
		title1='HAM='+strtrim(string(ih+1),2)

		ymax=max(T_cav_2[*,ih,col])
		plot,T_cav_2[*,ih,col],xtit='Scan',ytit='T_cav',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

		oplot,T_cav_2[*,ih,col],symsize=1,color=lcol[col],psym=symbol[col]
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
ENDFOR


;*****************************************************************************
;  SH temperature over scans.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='T_sh vs Scan and Collect for HAM A'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_sh',yrange=[T_sh[0,0]-1.5,T_sh[0,0]+1.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_sh_2[0:maxscans-1,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='T_sh vs Scan and Collect for HAM B'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_sh',yrange=[T_sh[0,0]-1.5,T_sh[0,0]+1.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_sh_2[0:maxscans-1,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_sh vs Scan, HAM=A'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_sh_2[*,0,col])
	plot,T_sh_2[*,0,col],xtit='Scan',ytit='T_sh',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_sh_2[*,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_sh vs Scan, HAM=B'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_sh_2[*,0,col])
	plot,T_sh_2[*,1,col],xtit='Scan',ytit='T_sh',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_sh_2[*,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_sh vs Scan: Collect='+strtrim(string(col+1),2)
	FOR ih=0, nham-1 DO BEGIN
		title1='HAM='+strtrim(string(ih+1),2)

		ymax=max(T_sh_2[*,ih,col])
		plot,T_sh_2[*,ih,col],xtit='Scan',ytit='T_sh',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

		oplot,T_sh_2[*,ih,col],symsize=1,color=lcol[col],psym=symbol[col]
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
ENDFOR

;*****************************************************************************
;  HAM temperature over scans.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='T_ham vs Scan and Collect for HAM A'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_ham',yrange=[T_ham[0,0]-1.5,T_ham[0,0]+1.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_ham_2[0:maxscans-1,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='T_ham vs Scan and Collect for HAM B'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='T_ham',yrange=[T_ham[0,0]-1.5,T_ham[0,0]+1.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_ham_2[0:maxscans-1,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_ham vs Scan, HAM=A'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_ham_2[*,0,col])
	plot,T_ham_2[*,0,col],xtit='Scan',ytit='T_ham',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_ham_2[*,0,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='T_ham vs Scan, HAM=B'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_ham_2[*,0,col])
	plot,T_ham_2[*,1,col],xtit='Scan',ytit='T_ham',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_ham_2[*,1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_ham vs Scan: Collect='+strtrim(string(col+1),2)
	FOR ih=0, nham-1 DO BEGIN
		title1='HAM='+strtrim(string(ih+1),2)

		ymax=max(T_ham_2[*,ih,col])
		plot,T_ham_2[*,ih,col],xtit='Scan',ytit='T_ham',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

		oplot,T_ham_2[*,ih,col],symsize=1,color=lcol[col],psym=symbol[col]
		XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
	ENDFOR
ENDFOR

;*****************************************************************************
;  CFPA temperature.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='SMWIR T_cfpa vs Scan and Collect'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='SMWIR T_cfpa',yrange=[T_cfpa[0,0]-.5,T_cfpa[0,0]+.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_cfpa_1[0,0:maxscans-1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='LWIR T_cfpa vs Scan and Collect'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='LWIR T_cfpa',yrange=[T_cfpa[1,0]-.5,T_cfpa[1,0]+.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_cfpa_1[1,0:maxscans-1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='SMWIR T_cfpa vs Scan'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_cfpa_1[0,*,col])
	plot,T_cfpa_1[0,*,col],xtit='Scan',ytit='SMWIR T_cfpa',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_cfpa_1[0,*,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='LWIR T_cfpa vs Scan'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_cfpa_1[1,*,col])
	plot,T_cfpa_1[1,*,col],xtit='Scan',ytit='LWIR T_cfpa',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_cfpa_1[1,*,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_cpfa vs Scan: Collect='+strtrim(string(col+1),2)
	title1='SMWIR'

	ymax=max(T_cfpa_1[0,*,col])
	plot,T_cfpa_1[0,*,col],xtit='Scan',ytit='SMWIR T_cfpa',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_cfpa_1[0,*,col],symsize=1,color=lcol[col],psym=symbol[col]

	title1='LWIR'

	ymax=max(T_cfpa_1[1,*,col])
	plot,T_cfpa_1[1,*,col],xtit='Scan',ytit='LWIR T_cfpa',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_cfpa_1[1,*,col],symsize=1,color=lcol[col],psym=symbol[col]
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

;*****************************************************************************
;  OMM temperature.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='Aperature stop T_omm vs Scan and Collect'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='Aperature stop T_omm',yrange=[T_omm[0,0]-.5,T_omm[0,0]+.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_omm_1[0,0:maxscans-1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='Bulkhead T_omm vs Scan and Collect'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='Bulkhead T_omm',yrange=[T_omm[1,0]-.5,T_omm[1,0]+.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_omm_1[1,0:maxscans-1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='Aperature stop T_omm vs Scan'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_omm_1[0,*,col])
	plot,T_omm_1[0,*,col],xtit='Scan',ytit='Aperature stop T_omm',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_omm_1[0,*,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='Bulkhead T_omm vs Scan'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_omm_1[1,*,col])
	plot,T_omm_1[1,*,col],xtit='Scan',ytit='Bulkhead T_omm',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_omm_1[1,*,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_omm vs Scan: Collect='+strtrim(string(col+1),2)
	title1='Aperature stop'

	ymax=max(T_omm_1[0,*,col])
	plot,T_omm_1[0,*,col],xtit='Scan',ytit='SAperature stop T_omm',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_omm_1[0,*,col],symsize=1,color=lcol[col],psym=symbol[col]

	title1='Bulkhead T_omm'

	ymax=max(T_omm_1[1,*,col])
	plot,T_omm_1[1,*,col],xtit='Scan',ytit='Bulkhead T_omm',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_omm_1[1,*,col],symsize=1,color=lcol[col],psym=symbol[col]
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
    ENDFOR

;*****************************************************************************
;  ASP temperature.
;*****************************************************************************

!p.multi=[0,1,1]
!p.position=0

title='SMWIR T_asp vs Scan and Collect'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='SMWIR T_asp',yrange=[T_mwasp[0]-.5,T_mwasp[0]+.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_mwasp_1[0:maxscans-1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

title='LWIR T_asp vs Scan and Collect'
plot,D[0:maxscans*ncollects],xtit='Collect*scan',ytit='LWIR T_asp',yrange=[T_lwasp[0]-.5,T_lwasp[0]+.5],charsize=1.2,charthick=5,/nodata

FOR col=0, ncollects-1 DO BEGIN
	oplot,D[maxscans*col:maxscans*(col+1)-1],T_lwasp_1[0:maxscans-1,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='SMWIR T_asp vs Scan'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_mwasp_1[*,col])
	plot,T_mwasp_1[*,col],xtit='Scan',ytit='SMWIR T_asp',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_mwasp_1[*,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,3,3]
!p.position=0

title='LWIR T_asp vs Scan'
FOR col=0, ncollects-1 DO BEGIN
	title1='Collect='+strtrim(string(col+1),2)

	ymax=max(T_lwasp_1[*,col])
	plot,T_lwasp_1[*,col],xtit='Scan',ytit='LWIR T_asp',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_lwasp_1[*,col],symsize=1,color=lcol[col],psym=symbol[col]
ENDFOR
XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5

!p.multi=[0,2,1]
!p.position=0

FOR col=0, ncollects-1 DO BEGIN
	title='T_asp vs Scan: Collect='+strtrim(string(col+1),2)
	title1='SMWIR'

	ymax=max(T_mwasp_1[*,col])
	plot,T_mwasp_1[*,col],xtit='Scan',ytit='SMWIR T_asp',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_mwasp_1[*,col],symsize=1,color=lcol[col],psym=symbol[col]

	title1='LWIR'

	ymax=max(T_lwasp_1[*,col])
	plot,T_lwasp_1[*,col],xtit='Scan',ytit='LWIR T_asp',yrange=[ymax-0.05,ymax+0.05],title=title1,charsize=1.2,charthick=5,/nodata

	oplot,T_lwasp_1[*,col],symsize=1,color=lcol[col],psym=symbol[col]
	XYOUTS,0.5,1.025,title,/normal,alignment=0.5,charsize=1.6,charthick=5
ENDFOR

device,/close

END
